package Weed::FieldTypes;
use Weed::Perl;

use Weed::FieldTypes::SFBool;
use Weed::FieldTypes::SFColor;
use Weed::FieldTypes::SFColorRGBA;
use Weed::FieldTypes::SFDouble;
use Weed::FieldTypes::SFFloat;
use Weed::FieldTypes::SFImage;
use Weed::FieldTypes::SFInt32;
use Weed::FieldTypes::SFNode;
use Weed::FieldTypes::SFRotation;
use Weed::FieldTypes::SFString;
use Weed::FieldTypes::SFTime;
use Weed::FieldTypes::SFVec2d;
use Weed::FieldTypes::SFVec2f;
use Weed::FieldTypes::SFVec3d;
use Weed::FieldTypes::SFVec3f;

use Weed::FieldTypes::MFBool;
use Weed::FieldTypes::MFColor;
use Weed::FieldTypes::MFColorRGBA;
use Weed::FieldTypes::MFDouble;
use Weed::FieldTypes::MFFloat;
use Weed::FieldTypes::MFImage;
use Weed::FieldTypes::MFInt32;
use Weed::FieldTypes::MFNode;
use Weed::FieldTypes::MFRotation;
use Weed::FieldTypes::MFString;
use Weed::FieldTypes::MFTime;
use Weed::FieldTypes::MFVec2d;
use Weed::FieldTypes::MFVec2f;
use Weed::FieldTypes::MFVec3d;
use Weed::FieldTypes::MFVec3f;

1;
__END__
